Gitweb:     
http://git.kernel.org/git/?p=linux/kernel/git/torvalds/linux-2.6.git;a=commit;h=8d06bfadb44bfec067603fbc8ee2faced3b13ad9
Commit:     8d06bfadb44bfec067603fbc8ee2faced3b13ad9
Parent:     97219851b92fd083539003bca48c379d415566ac
Author:     Borislav Petkov <[EMAIL PROTECTED]>
AuthorDate: Wed Feb 6 02:57:53 2008 +0100
Committer:  Bartlomiej Zolnierkiewicz <[EMAIL PROTECTED]>
CommitDate: Wed Feb 6 02:57:53 2008 +0100

    ide-tape: shorten some function names
    
    Signed-off-by: Borislav Petkov <[EMAIL PROTECTED]>
    Signed-off-by: Bartlomiej Zolnierkiewicz <[EMAIL PROTECTED]>
---
 drivers/ide/ide-tape.c |   32 +++++++++++++++-----------------
 1 files changed, 15 insertions(+), 17 deletions(-)

diff --git a/drivers/ide/ide-tape.c b/drivers/ide/ide-tape.c
index 27fd33d..bdf02fc 100644
--- a/drivers/ide/ide-tape.c
+++ b/drivers/ide/ide-tape.c
@@ -1090,7 +1090,7 @@ typedef void idetape_io_buf(ide_drive_t *, idetape_pc_t 
*, unsigned int);
  * command. We will transfer some of the data (as requested by the drive) and
  * will re-point interrupt handler to us. When data transfer is finished, we
  * will act according to the algorithm described before
- * idetape_issue_packet_command.
+ * idetape_issue_pc.
  */
 static ide_startstop_t idetape_pc_intr(ide_drive_t *drive)
 {
@@ -1267,7 +1267,7 @@ static ide_startstop_t idetape_pc_intr(ide_drive_t *drive)
  *
  *     The handling will be done in three stages:
  *
  *     1.      idetape_issue_packet_command will send the packet command to the
  *             drive, and will set the interrupt handler to idetape_pc_intr.
  *
  *     2.      On each interrupt, idetape_pc_intr will be called. This step
@@ -1342,7 +1342,7 @@ static ide_startstop_t idetape_transfer_pc(ide_drive_t 
*drive)
        return ide_started;
 }
 
-static ide_startstop_t idetape_issue_packet_command (ide_drive_t *drive, 
idetape_pc_t *pc)
+static ide_startstop_t idetape_issue_pc(ide_drive_t *drive, idetape_pc_t *pc)
 {
        ide_hwif_t *hwif = drive->hwif;
        idetape_tape_t *tape = drive->driver_data;
@@ -1649,7 +1649,7 @@ static ide_startstop_t idetape_do_request(ide_drive_t 
*drive,
         */
        if (tape->failed_pc != NULL &&
            tape->pc->c[0] == REQUEST_SENSE) {
-               return idetape_issue_packet_command(drive, tape->failed_pc);
+               return idetape_issue_pc(drive, tape->failed_pc);
        }
        if (postponed_rq != NULL)
                if (rq != postponed_rq) {
@@ -1730,7 +1730,7 @@ static ide_startstop_t idetape_do_request(ide_drive_t 
*drive,
        }
        BUG();
 out:
-       return idetape_issue_packet_command(drive, pc);
+       return idetape_issue_pc(drive, pc);
 }
 
 /*
@@ -2280,11 +2280,8 @@ static int idetape_queue_rw_tail(ide_drive_t *drive, int 
cmd, int blocks, struct
        return (tape->blk_size * (blocks-rq.current_nr_sectors));
 }
 
-/*
- *     idetape_insert_pipeline_into_queue is used to start servicing the
- *     pipeline stages, starting from tape->next_stage.
- */
-static void idetape_insert_pipeline_into_queue (ide_drive_t *drive)
+/* start servicing the pipeline stages, starting from tape->next_stage. */
+static void idetape_plug_pipeline(ide_drive_t *drive)
 {
        idetape_tape_t *tape = drive->driver_data;
 
@@ -2376,7 +2373,7 @@ static int idetape_add_chrdev_write_request (ide_drive_t 
*drive, int blocks)
                        spin_unlock_irqrestore(&tape->lock, flags);
                } else {
                        spin_unlock_irqrestore(&tape->lock, flags);
-                       idetape_insert_pipeline_into_queue(drive);
+                       idetape_plug_pipeline(drive);
                        if (idetape_pipeline_active(tape))
                                continue;
                        /*
@@ -2413,7 +2410,7 @@ static int idetape_add_chrdev_write_request (ide_drive_t 
*drive, int blocks)
                        tape->insert_time = jiffies;
                        tape->insert_size = 0;
                        tape->insert_speed = 0;
-                       idetape_insert_pipeline_into_queue(drive);
+                       idetape_plug_pipeline(drive);
                }
        }
        if (test_and_clear_bit(IDETAPE_PIPELINE_ERROR, &tape->flags))
@@ -2432,7 +2429,7 @@ static void idetape_wait_for_pipeline (ide_drive_t *drive)
        unsigned long flags;
 
        while (tape->next_stage || idetape_pipeline_active(tape)) {
-               idetape_insert_pipeline_into_queue(drive);
+               idetape_plug_pipeline(drive);
                spin_lock_irqsave(&tape->lock, flags);
                if (idetape_pipeline_active(tape))
                        idetape_wait_for_request(drive, tape->active_data_rq);
@@ -2525,7 +2522,7 @@ static void idetape_restart_speed_control (ide_drive_t 
*drive)
        tape->controlled_previous_head_time = 
tape->uncontrolled_previous_head_time = jiffies;
 }
 
-static int idetape_initiate_read (ide_drive_t *drive, int max_stages)
+static int idetape_init_read(ide_drive_t *drive, int max_stages)
 {
        idetape_tape_t *tape = drive->driver_data;
        idetape_stage_t *new_stage;
@@ -2586,7 +2583,7 @@ static int idetape_initiate_read (ide_drive_t *drive, int 
max_stages)
                        tape->insert_time = jiffies;
                        tape->insert_size = 0;
                        tape->insert_speed = 0;
-                       idetape_insert_pipeline_into_queue(drive);
+                       idetape_plug_pipeline(drive);
                }
        }
        return 0;
@@ -2616,7 +2613,7 @@ static int idetape_add_chrdev_read_request (ide_drive_t 
*drive,int blocks)
         * Wait for the next block to be available at the head
         * of the pipeline
         */
-       idetape_initiate_read(drive, tape->max_stages);
+       idetape_init_read(drive, tape->max_stages);
        if (tape->first_stage == NULL) {
                if (test_bit(IDETAPE_PIPELINE_ERROR, &tape->flags))
                        return 0;
@@ -2879,7 +2876,8 @@ static ssize_t idetape_chrdev_read (struct file *file, 
char __user *buf,
                            (count % tape->blk_size) == 0)
                                tape->user_bs_factor = count / tape->blk_size;
        }
-       if ((rc = idetape_initiate_read(drive, tape->max_stages)) < 0)
+       rc = idetape_init_read(drive, tape->max_stages);
+       if (rc < 0)
                return rc;
        if (count == 0)
                return (0);
-
@@ -1267,7 +1267,7 @@ static ide_startstop_t idetape_pc_intr(ide_drive_t *drive)
  *     The handling will be done in three stages:
  *
- *     1.      idetape_issue_packet_command will send the packet command to the
+ *     1.      idetape_issue_pc will send the packet command to the
  *             drive, and will set the interrupt handler to idetape_pc_intr.
  *
To unsubscribe from this list: send the line "unsubscribe git-commits-head" in
the body of a message to [EMAIL PROTECTED]
More majordomo info at  http://vger.kernel.org/majordomo-info.html

Reply via email to